//
//  TVOError.h
//  TwilioVoice
//
//  Copyright © 2018 Twilio, Inc. All rights reserved.
//

#ifndef TVOError_h
#define TVOError_h

FOUNDATION_EXPORT NSString * _Nonnull const kTVOErrorDomain;

/**
 * An enumeration indicating the errors that can be raised by the SDK.
 */
typedef NS_ENUM (NSInteger, TVOError) {
    TVOErrorAccessTokenInvalidError                       = 20101,    ///< Invalid Access Token
    TVOErrorAccessTokenHeaderInvalidError                 = 20102,    ///< Invalid Access Token header
    TVOErrorAccessTokenIssuerInvalidError                 = 20103,    ///< Invalid Access Token issuer/subject
    TVOErrorAccessTokenExpiredError                       = 20104,    ///< Access Token expired or expiration date invalid
    TVOErrorAccessTokenNotYetValidError                   = 20105,    ///< Access Token not yet valid
    TVOErrorAccessTokenGrantsInvalidError                 = 20106,    ///< Invalid Access Token grants
    TVOErrorAccessTokenSignatureInvalidError              = 20107,    ///< Invalid Access Token signature
    TVOErrorAuthFailureCodeError                          = 20151,    ///< Auth Failure Error
    TVOErrorExpirationTimeExceedsMaxTimeAllowedError      = 20157,    ///< Expiration Time Exceeds Maximum Time Allowed
    TVOErrorAccessForbiddenError                          = 20403,    ///< The account lacks permission to access the Twilio API
    TVOErrorApplicationNotFoundError                      = 21218,    ///< Invalid Application Sid
    TVOErrorConnectionTimeoutError                        = 31003,    ///< Connection timeout
    TVOErrorInitializationError                           = 31004,    ///< Initialization error
    TVOErrorConnectionError                               = 31005,    ///< Connection error
    TVOErrorCallCancelledError                            = 31008,    ///< Unable to answer because the call has ended
    TVOErrorMalformedRequestError                         = 31100,    ///< Malformed request
    TVOErrorInvalidDataError                              = 31106,    ///< Invalid data
    TVOErrorAuthorizationError                            = 31201,    ///< Authorization error
    TVOErrorInvalidJWTTokenError                          = 31204,    ///< Invalid JWT token
    TVOErrorMicrophoneAccessDenialError                   = 31208,    ///< User denied access to microphone
    TVOErrorRegistrationError                             = 31301,    ///< Registration error
    TVOErrorTokenAuthenticationRejected                   = 51007,    ///< Token authentication is rejected by authentication service
    TVOErrorSignalingConnectionError                      = 53000,    ///< Signaling connection error
    TVOErrorSignalingConnectionDisconnectedError          = 53001,    ///< Signaling connection disconnected
    TVOErrorSignalingConnectionTimeoutError               = 53002,    ///< Signaling connection timed out
    TVOErrorSignalingIncomingMessageInvalidError          = 53003,    ///< Client received an invalid signaling message
    TVOErrorSignalingOutgoingMessageInvalidError          = 53004,    ///< Client sent an invalid signaling message
    TVOErrorMediaClientLocalDescFailedError               = 53400,    ///< Client is unable to create or apply a local media description
    TVOErrorMediaServerLocalDescFailedError               = 53401,    ///< Server is unable to create or apply a local media description
    TVOErrorMediaClientRemoteDescFailedError              = 53402,    ///< Client is unable to apply a remote media description
    TVOErrorMediaServerRemoteDescFailedError              = 53403,    ///< Server is unable to apply a remote media description
    TVOErrorMediaNoSupportedCodecError                    = 53404,    ///< No supported codec
    TVOErrorMediaConnectionError                          = 53405,    ///< Media connection failed
    TVOErrorConfigurationAcquireFailedError               = 53500,    ///< Unable to acquire configuration
    TVOErrorConfigurationAcquireTurnFailedError           = 53501     ///< Unable to acquire TURN credentials
};

#endif
